@@ -7,20 +7,16 @@ class CloudProvider(str, Enum):
     AZURE = 'azure'
 
 
-class CloudCredentials:
-    pass
-
-
 class CloudScanSettings:
     def __init__(self,
                  cloud_provider: CloudProvider,
                  account_name: str,
-                 should_clean_before_collect: bool,
+                 should_clean_before_scan: bool,
                  output_path: str,
                  commands_path: str):
         self.cloud_provider: CloudProvider = cloud_provider
         self.account_name: str = account_name
-        self.clean: bool = should_clean_before_collect
+        self.clean: bool = should_clean_before_scan
         self.output_path: str = output_path
         self.commands_path: str = commands_path
 
