@@ -2,24 +2,21 @@ import os
 
 import click
 from click_aliases import ClickAliasedGroup
+
+from dragoneye.version import __version__
 from dragoneye.cloud_scanner.aws.aws_scanner import AwsScanner
-
 from dragoneye.cloud_scanner.aws.aws_session_factory import AwsSessionFactory
-
 from dragoneye.cloud_scanner.azure.azure_scanner import AzureScanner
-
 from dragoneye.cloud_scanner.azure.azure_authorizer import AzureAuthorizer
-
 from dragoneye.cloud_scanner.aws.aws_scan_settings import AwsCloudScanSettings
-from dragoneye.cloud_scanner.aws.aws_utils import AwsUtils
 from dragoneye.cloud_scanner.azure.azure_scan_settings import AzureCloudScanSettings
 from dragoneye.utils.value_validator import validate_uuid, validate_path
 
 
 @click.group(name='scan',
-             short_help='Scan cloud account.',
-             help='Scan cloud account. Currently supported: AWS, Azure',
+             help='Execute data-fetching API commands on a cloud account at a large scale quickly. Currently supported: AWS, Azure',
              cls=ClickAliasedGroup)
+@click.version_option(__version__)
 def scan_cli():
     pass
 
@@ -33,9 +30,12 @@ def safe_cli_entry_point():
 
 @scan_cli.command(name='azure',
                   short_help='Scan an Azure cloud account',
-                  help='Scan an Azure cloud account.')
+                  help='Scan an Azure cloud account. '
+                       '\n\nSCAN_COMMANDS_PATH: The file path to the yaml file that contains all the scan commands to run')
+@click.argument('scan-commands-path',
+                type=click.STRING)
 @click.option('--cloud-account-name', '-n',
-              help='The name of your cloud account',
+              help='The name of your cloud account, the default value is \'default\'',
               type=click.STRING,
               default='default')
 @click.option('--subscription-id', '-i',
@@ -54,10 +54,6 @@ def safe_cli_entry_point():
               help='The client secret created in Azure connect to cloudrail',
               type=click.STRING,
               required=True)
-@click.option('--scan-commands-path',
-              help='The file path to the yaml file that contains all the scan commands to run',
-              type=click.STRING,
-              required=True)
 @click.option("--clean",
               help="Remove any existing data for the account before gathering",
               is_flag=True,
@@ -88,9 +84,11 @@ def azure(cloud_account_name: str,
 
 @scan_cli.command(name='aws',
                   short_help='Scan an AWS cloud account',
-                  help='Scan an AWS cloud account.')
+                  help='Scan an AWS cloud account. \n\nSCAN_COMMANDS_PATH: The file path to the yaml file that contains all the scan commands to run')
+@click.argument('scan-commands-path',
+                type=click.STRING)
 @click.option('--cloud-account-name', '-n',
-              help='The name of your cloud account',
+              help='The name of your cloud account, the default value is \'default\'',
               type=click.STRING,
               default='default')
 @click.option('--profile',
@@ -100,10 +98,6 @@ def azure(cloud_account_name: str,
               help="Filter and query AWS only for the given regions (comma separated)",
               type=click.STRING,
               default='')
-@click.option('--scan-commands-path',
-              help='The file path to the yaml file that contains all the scan commands to run',
-              type=click.STRING,
-              required=True)
 @click.option("--clean",
               help="Remove any existing data for the account before gathering",
               is_flag=True,
@@ -112,26 +106,26 @@ def azure(cloud_account_name: str,
               help='The path in which the scan results will be saved on. Defaults to current working directory.',
               type=click.STRING,
               default=os.getcwd())
-@click.option('--api-region',
-              help='The region to invoke the api calls against',
-              type=click.STRING,
-              default=AwsUtils.get_api_region())
+@click.option('--default-region',
+              help='The default region for scanning universal services. Defaults to the value of the AWS_DEFAULT_REGION environment variable.',
+              type=click.STRING)
 def aws(cloud_account_name,
         profile,
         regions,
         scan_commands_path,
         clean,
         output_path,
-        api_region):
+        default_region):
     aws_scan_settings = AwsCloudScanSettings(
         commands_path=scan_commands_path,
         account_name=cloud_account_name,
         regions_filter=regions.split(','),
         should_clean_before_scan=clean,
-        output_path=output_path)
+        output_path=output_path,
+        default_region=default_region)
 
     validate_path(scan_commands_path)
-    session = AwsSessionFactory.get_session(profile, api_region)
+    session = AwsSessionFactory.get_session(profile, default_region)
     output_path = AwsScanner(session, aws_scan_settings).scan()
     click.echo(f'Results saved to {output_path}')
 
